AmrPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AmrPluginPlatform
Implementers

Constructors

AmrPluginPlatform()
Constructs a AmrPluginPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

convertAmrToWav(String amrPath, {int sampleRate = 22050}) → Future<String?>
convertWavToAmr(String wavPath, {int sampleRate = 8000, int bitRate = 12200}) → Future<String?>
getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testMediaCodecSupport() → Future<Map<String, dynamic>?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AmrPluginPlatform
The default instance of AmrPluginPlatform to use.
getter/setter pair